Skip to contents

Provides a brief summary of the package libraries on your machine. I'm so excited to have written this!

Usage

lib_summary(sizes = FALSE)

Arguments

sizes

Logical. Requests the size of the package library on disk.

Value

A data.frame containing the count of packages in each of the user's libraries. If sizes is TRUE, also gives library size.

Examples

lib_summary()
#>                           Library n_packages
#> 1 /home/runner/work/_temp/Library         66
#> 2      /opt/R/4.5.0/lib/R/library         29
#> 3 /opt/R/4.5.0/lib/R/site-library          1